==> flutter_uikit_forzzh-0.1.3.tar.gz: README.md <==
# pubspec.yaml 依赖
    dependencies:
      flutter_uikit_forzzh: ^0.1.3


# flutter 常用组件ui库
 1. 可自定义日历组件
 2. 输入框搜索组件，支持Flutter 中 TextField 全部属性
 3. 进度条组件(条形和圆形)
 4. 评分组件
 5. 吐司提示,可完全自定义
 6. 灵活popwindow组件
 7. 城市picker
 8. 复选框，单选，气泡,抽屉组件等
 9. 倒计时控件
 10. 增加类似android TextView 上下左右可添加元素组件
 11. 添加可自定大小的switch组件
 12. 新增表格布局 tableview 
 13. 新增 MarqueeView 跑马灯组件
 14. 新增 InfiniteLevelsMenus 无限层级菜单
 15. 新增 InputText 极简输入框,支持实时表单校验,支持 TextField和 TextFormField全部属性。
 16. 新增 FloatExpendButton 悬浮菜单按钮

  ...持续更新中....

# 最后一次提交记录摘要

  1.新增 FloatExpendButton 悬浮菜单按钮
  2.InputExtend 扩展新功能
  3.修复 Toast bug
  4.MarqueeView 新增垂直滚动效果。
  5.新加一些工具类
  



## 更多效果请查看demo


## 日历组件：

![](https://github.com/zhengzaihong/uikit/blob/master/images/calendar.gif)


## 极简输入框支持TextField 和TextFormField全部属性，支持实时表单校验
![](https://github.com/zhengzaihong/uikit/blob/master/images/input_text.gif)



## 输入框拓展搜索组件：

![](https://github.com/zhengzaihong/uikit/blob/master/images/inputextentd.gif)

## 可伸展的悬浮按钮
![](https://github.com/zhengzaihong/uikit/blob/master/images/float_button.gif)

## 城市选择器：
![](https://github.com/zhengzaihong/uikit/blob/master/images/citypicker.gif)


## 可定制的Toast：
![](https://github.com/zhengzaihong/uikit/blob/master/images/toast.gif)

## 弹窗组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/popwindow.gif)


## 进度条组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/progressbar.gif)

## 无限层级菜单：
![](https://github.com/zhengzaihong/uikit/blob/master/images/one_expand.gif)
![](https://github.com/zhengzaihong/uikit/blob/master/images/all_expand.gif)

## 表格组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/tabview1.png)
![](https://github.com/zhengzaihong/uikit/blob/master/images/tabview2.png)





## 其他常用小组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/widgets.gif)

==> flutter_uikit_forzzh-0.1.5.tar.gz: README.md <==
# pubspec.yaml 依赖
    dependencies:
      flutter_uikit_forzzh: ^0.1.5


# flutter 常用组件ui库
 1. 可自定义日历组件
 2. 输入框搜索组件，支持Flutter 中 TextField 全部属性
 3. 进度条组件(条形和圆形)
 4. 评分组件
 5. 吐司提示,可完全自定义
 6. 浮窗PopupWindow组件
 7. 城市picker
 8. 复选框，单选，气泡,抽屉组件等
 9. 倒计时控件
 10. 增加类似android TextView 上下左右可添加元素组件
 11. 添加可自定大小的switch组件
 12. 新增表格布局 tableview ，新增横向和纵向都可滚动功能。
 13. 新增 MarqueeView 跑马灯组件
 14. 新增 InfiniteLevelsMenus 无限层级菜单，简化使用逻辑
 15. 新增 InputText 极简输入框,支持实时表单校验,支持 TextField和 TextFormField全部属性。
 16. 新增 FloatExpendButton 悬浮菜单按钮
 17. 新增 CustomAnimatedBottomBar 底部菜单
 18. 新增分页组件 Pager.
 19. 新增选择下拉框菜单 SelectionMenu 可高度自定义，且不关注数据本身。
 20. 新增 TextExtend 文本拓展组件，支持web 前端js菜单效果。
 21. 新增 MousePopupButton 鼠标右键弹出窗组件，再Web端使用

  ...持续更新中....





## 更多效果请查看demo


## 日历组件：

![](https://github.com/zhengzaihong/uikit/blob/master/images/calendar.gif)


## 极简输入框支持TextField 和TextFormField全部属性，支持实时表单校验
![](https://github.com/zhengzaihong/uikit/blob/master/images/input_text.gif)



## 输入框拓展搜索组件：

![](https://github.com/zhengzaihong/uikit/blob/master/images/inputextentd.gif)

## 可伸展的悬浮按钮
![](https://github.com/zhengzaihong/uikit/blob/master/images/float_button.gif)

## 仿web前端 js菜单
![](https://github.com/zhengzaihong/uikit/blob/master/images/text_extend.gif)
![](https://github.com/zhengzaihong/uikit/blob/master/images/text_extend2.gif)

## 城市选择器：
![](https://github.com/zhengzaihong/uikit/blob/master/images/citypicker.gif)


## 可定制的Toast：
![](https://github.com/zhengzaihong/uikit/blob/master/images/toast.gif)

## 弹窗组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/popwindow.gif)


## 可高度自定义的选择下拉框组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/SelectionMenu.gif)


## WEB 中鼠标右键弹窗组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/MousePopupButton-Web.gif)

## 进度条组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/progressbar.gif)

## 无限层级菜单：
![](https://github.com/zhengzaihong/uikit/blob/master/images/one_expand.gif)

## 表格组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/table_scroller.gif)
![](https://github.com/zhengzaihong/uikit/blob/master/images/tabview1.png)



## 分页组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/pager_image.png)

## 其他常用小组件：
![](https://github.com/zhengzaihong/uikit/blob/master/images/widgets.gif)
